function split = groupsplit(ilist,grouplist,nfold,seed)

% split = groupsplit(ilist,grouplist,nfold,seed)
%
% Create nfold random splits of the list ilist into a train and a test
% sets, in such a way that all elements of ilist appear only once in a test
% list, and that two elements of the same group (as indicated in grouplist)
% always appear in the same split
%
% INPUT
%  - ilist : a vector of integers to be split
%  - grouplist : a vector of integers, of the same size as ilist, that
%  assigns a group id to each element of ilist
%  - nfold : how many splits should be created
%  - seed (optional): the random number generator seed
%
% OUTPUT
%  an array with components s{i}.train and s{i}.test, for 1 <= i <= nfold

if nargin>3
    rand('seed',seed);
end
    
[B,I,J]=unique(grouplist);
r=randperm(length(B));
randgroup=r(J);
% preallocation
split = cell(1, nfold);
% initialization
for k=1:nfold
split{k} = struct('train', [], 'test', []);
end

for i=0:nfold-1
    split{i+1}.train = ilist(mod(randgroup,nfold) ~= i);
    split{i+1}.test = ilist(mod(randgroup,nfold) == i);
end
