function  a = sirene_cytoscape(scores, threshold, sireneData, varargin)


% USAGE:
%   sirene_cytoscape(scores, threshold, sireneData, varargin)
%
%   - prints the predicted network in a file for further processing with
%     Cytoscape
%   - summarizes the prediction for different levels of precision
%     and prints this information in text files
%
% INPUT:
%   - scores = a (N-k) X s matrix of scores corresponding to the edges starting 
%     from the s source vertices to the (N-k) vertices such as produced by
%     function sirene_predict_simplesvm or sirene_predict_libsvm
%   - threshold = a structure such as obtained by function sirene_analyze
%     with three components :
%     o result.precision : a vector of precision levels which the user wants to test
%     o result.threshold : the vector of corresponding thresholds for
%       prediction.
%     o result.recall : a vector with the corresponding levels of recall
%       obtained from the precision/recall curve
%
% ADDITIONAL ARGUMENTS:
%   - resultpath : the path where the produced files will be saved
%     (default : in current directory)
%
% OUTPUT:
% 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Default behaviour
cytofilenames = cell(1, length(threshold.precision));
for i=1:length(threshold.precision)
cytofilenames{i} = strcat('cytofile', num2str(floor(100*threshold.precision(i))), '.txt');
end
resultpath = './';
resultfile = 'nb_new_pred.txt';

% Parse optional arguments
l=1;
while (l<length(varargin))
   eval(strcat(varargin{l},' = ''', varargin{l+1}, ''';'));
    l = l+2;
end

if length(cytofilenames) ~= length(threshold.precision)
    error('argument cytofilenames should be of the same length as threshold.precision since one file is produced per level of precision')
end

% Read gene names
if isempty(sireneData.geneFile)
    g = num2cell(1:sireneData.nvertex) ;
else
eval(strcat('fid = fopen(''', sireneData.geneFile, ''', ''rt'');'));
g = textscan(fid,'%s');
g = g{1};
fclose(fid)
end


% Print the graph information
for k = 1:length(cytofilenames)
    eval(strcat('fid = fopen(''', resultpath , char(cytofilenames(k)),''',''w'');'));
    for i=1:sireneData.nsource
        for j=1:length(sireneData.toPredict)
            if scores(j,i)>threshold.threshold(k)
                fprintf(fid,'%s\t',num2str(g{sireneData.source(i)}));
                fprintf(fid,'%s\n',num2str(g{sireneData.toPredict(j)}));
                
            end
        end
    end
    fclose(fid);
end

% Print general information
eval(strcat(['fid = fopen(''', resultpath, resultfile,''',''w'');']));
for k = 1:length(threshold.precision)  
    prec = threshold.precision(k);
    th = threshold.threshold(k);
    rec = threshold.recall(k);
    if th == +inf
        fprintf(fid, 'Warning : level of precision  %d %% not reached', floor(100*prec));
    else
        total = sum(sum(scores > th));
        % print the information associated to each level of precision
        fprintf(fid,'Precision=%d %% \t Recall : %5.2f %% \t Threshold : %f\t Total : %u predicted new regulations\n', floor(100*prec), 100*rec, th, total);
    end
end
fclose(fid);