function  scores = sirene_predict_simplesvm(sireneData)
%
% USAGE:
% scores = sirene_predict(sireneData)
%
% Predict new edges with SIRENE using simpleSVM
%
% REQUIRED:
%  - simpleSVM should be on the path
%
% INPUTS:
%  - sireneData : a structure containing the features, the edges and
%  various parameters, as initialized by sirene_initialize()
% 
% OUTPUT:
%  a (N-k) X s matrix of scores corresponding to the edges starting from the s
%  source vertices to the N-k vertices of sireneData.toPredict


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% build the kernel
if (strcmp(sireneData.kernelType , 'rbf'))
ker = kernel('rbf',1/(2*sireneData.param*sireneData.param));
else
ker = kernel (sireneData.kernelType, sireneData.param);
end

% Matrix of known edges starting from vertices in the sourcevertices list
% (one column for each source vertex)
[~, ~, indSource]=unique(sireneData.edge(:,1));
Bgold = -ones(sireneData.nvertex,sireneData.nsource);
for i=1:sireneData.nedge
    Bgold(sireneData.edge(i,2),indSource(i)) = 1;
end


% prediction loop

scores = zeros(length(sireneData.toPredict),sireneData.nsource);
alltrain = sireneData.knownTargets;
alltest = sireneData.toPredict;

for isource=1:sireneData.nsource
    
    trainlabels = Bgold(sireneData.knownTargets,isource);
    testlabels = Bgold(sireneData.toPredict,isource);

    pa = param(sireneData.C,100,'binary','chol');
    mydata = data(alltrain',trainlabels,alltest',testlabels);
    clear global svModel;
    global svModel;
    trainSVM(mydata,ker,pa);
    scores(:,isource) = testSVM;

end




